@@ -1,6 +1,6 @@
-/* 
+/*
  * Copyright © 2012, 2013 Intel Corporation
- * 
+ *
  * Permission to use, copy, modify, distribute, and sell this
  * software and its documentation for any purpose is hereby granted
  * without fee, provided that the above copyright notice appear in
@@ -12,7 +12,7 @@
  * representations about the suitability of this software for any
  * purpose.  It is provided "as is" without express or implied
  * warranty.
- * 
+ *
  * THE COPYRIGHT HOLDERS DISCLAIM ALL WARRANTIES WITH REGARD TO THIS
  * SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND
  * FITNESS, IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY
@@ -407,6 +407,18 @@ wl_text_input_add_listener(struct wl_text_input *wl_text_input,
 #define WL_TEXT_INPUT_COMMIT_STATE	9
 #define WL_TEXT_INPUT_INVOKE_ACTION	10
 
+#define WL_TEXT_INPUT_ACTIVATE_SINCE_VERSION	1
+#define WL_TEXT_INPUT_DEACTIVATE_SINCE_VERSION	1
+#define WL_TEXT_INPUT_SHOW_INPUT_PANEL_SINCE_VERSION	1
+#define WL_TEXT_INPUT_HIDE_INPUT_PANEL_SINCE_VERSION	1
+#define WL_TEXT_INPUT_RESET_SINCE_VERSION	1
+#define WL_TEXT_INPUT_SET_SURROUNDING_TEXT_SINCE_VERSION	1
+#define WL_TEXT_INPUT_SET_CONTENT_TYPE_SINCE_VERSION	1
+#define WL_TEXT_INPUT_SET_CURSOR_RECTANGLE_SINCE_VERSION	1
+#define WL_TEXT_INPUT_SET_PREFERRED_LANGUAGE_SINCE_VERSION	1
+#define WL_TEXT_INPUT_COMMIT_STATE_SINCE_VERSION	1
+#define WL_TEXT_INPUT_INVOKE_ACTION_SINCE_VERSION	1
+
 static inline void
 wl_text_input_set_user_data(struct wl_text_input *wl_text_input, void *user_data)
 {
@@ -419,6 +431,12 @@ wl_text_input_get_user_data(struct wl_text_input *wl_text_input)
 	return wl_proxy_get_user_data((struct wl_proxy *) wl_text_input);
 }
 
+static inline uint32_t
+wl_text_input_get_version(struct wl_text_input *wl_text_input)
+{
+	return wl_proxy_get_version((struct wl_proxy *) wl_text_input);
+}
+
 static inline void
 wl_text_input_destroy(struct wl_text_input *wl_text_input)
 {
@@ -504,6 +522,8 @@ wl_text_input_invoke_action(struct wl_text_input *wl_text_input, uint32_t button
 
 #define WL_TEXT_INPUT_MANAGER_CREATE_TEXT_INPUT	0
 
+#define WL_TEXT_INPUT_MANAGER_CREATE_TEXT_INPUT_SINCE_VERSION	1
+
 static inline void
 wl_text_input_manager_set_user_data(struct wl_text_input_manager *wl_text_input_manager, void *user_data)
 {
@@ -516,6 +536,12 @@ wl_text_input_manager_get_user_data(struct wl_text_input_manager *wl_text_input_
 	return wl_proxy_get_user_data((struct wl_proxy *) wl_text_input_manager);
 }
 
+static inline uint32_t
+wl_text_input_manager_get_version(struct wl_text_input_manager *wl_text_input_manager)
+{
+	return wl_proxy_get_version((struct wl_proxy *) wl_text_input_manager);
+}
+
 static inline void
 wl_text_input_manager_destroy(struct wl_text_input_manager *wl_text_input_manager)
 {
